@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -13,9 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.drools.workbench.screens.dtablexls.client.editor;
 
 import java.util.List;
+import java.util.Optional;
 
 import com.google.gwtmockito.GwtMock;
 import com.google.gwtmockito.GwtMockitoTestRunner;
@@ -28,11 +30,13 @@ import org.drools.workbench.screens.dtablexls.client.type.DecisionTableXLSResour
 import org.drools.workbench.screens.dtablexls.client.type.DecisionTableXLSXResourceType;
 import org.drools.workbench.screens.dtablexls.service.DecisionTableXLSContent;
 import org.drools.workbench.screens.dtablexls.service.DecisionTableXLSService;
+import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.project.client.security.ProjectController;
-import org.guvnor.common.services.project.context.ProjectContext;
-import org.guvnor.common.services.project.model.Project;
+import org.guvnor.common.services.project.model.WorkspaceProject;
+import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.guvnor.common.services.shared.validation.model.ValidationMessage;
+import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.ErrorCallback;
 import org.jboss.errai.common.client.api.RemoteCallback;
@@ -42,6 +46,7 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilderImpl;
 import org.kie.workbench.common.widgets.client.popups.validation.ValidationPopup;
 import org.kie.workbench.common.widgets.metadata.client.KieEditorWrapperView;
+import org.kie.workbench.common.widgets.metadata.client.validation.AssetUpdateValidator;
 import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
@@ -50,7 +55,6 @@ import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilder;
-import org.uberfire.ext.editor.commons.client.validation.DefaultFileNameValidator;
 import org.uberfire.ext.widgets.common.client.common.BusyIndicatorView;
 import org.uberfire.ext.widgets.common.client.common.ConcurrentChangePopup;
 import org.uberfire.mocks.EventSourceMock;
@@ -58,8 +62,14 @@ import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.MenuItem;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertNull;
+import static org.mockito.Matchers.any;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 @WithClassesToStub({ConcurrentChangePopup.class})
@@ -95,9 +105,6 @@ public class DecisionTableXLSEditorPresenterTest {
     @Mock
     KieEditorWrapperView kieView;
 
-    @Mock
-    VersionRecordManager versionRecordManagerMock;
-
     @Mock
     EventSourceMock<NotificationEvent> notification;
 
@@ -118,7 +125,13 @@ public class DecisionTableXLSEditorPresenterTest {
     ProjectController projectController;
 
     @Mock
-    ProjectContext workbenchContext;
+    WorkspaceProjectContext workbenchContext;
+
+    @Mock
+    AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
+
+    @Mock
+    MenuItem alertsButtonMenuItem;
 
     DecisionTableXLSEditorPresenter presenter;
 
@@ -133,6 +146,8 @@ public class DecisionTableXLSEditorPresenterTest {
         when(decisionTableXLSXResourceType.accept(XLSPath)).thenReturn(false);
         when(decisionTableXLSXResourceType.accept(XLSXPath)).thenReturn(true);
 
+        when(alertsButtonMenuItemBuilder.build()).thenReturn(alertsButtonMenuItem);
+
         presenter = spy(new DecisionTableXLSEditorPresenter(view,
                                                             decisionTableXLSResourceType,
                                                             decisionTableXLSXResourceType,
@@ -144,20 +159,23 @@ public class DecisionTableXLSEditorPresenterTest {
             {
                 kieView = mock(KieEditorWrapperView.class);
                 overviewWidget = mock(OverviewWidgetPresenter.class);
-                versionRecordManager = versionRecordManagerMock;
                 concurrentUpdateSessionInfo = null;
                 fileMenuBuilder = DecisionTableXLSEditorPresenterTest.this.fileMenuBuilder;
                 projectController = DecisionTableXLSEditorPresenterTest.this.projectController;
                 workbenchContext = DecisionTableXLSEditorPresenterTest.this.workbenchContext;
                 versionRecordManager = DecisionTableXLSEditorPresenterTest.this.versionRecordManager;
+                alertsButtonMenuItemBuilder = DecisionTableXLSEditorPresenterTest.this.alertsButtonMenuItemBuilder;
             }
 
+            @Override
             protected void addSourcePage() {
 
             }
         });
 
         doReturn(mock(MenuItem.class)).when(presenter).getConvertMenu();
+        when(workbenchContext.getActiveOrganizationalUnit()).thenReturn(Optional.empty());
+        when(workbenchContext.getActiveWorkspaceProject()).thenReturn(Optional.empty());
     }
 
     @Test
@@ -184,9 +202,12 @@ public class DecisionTableXLSEditorPresenterTest {
 
     @Test
     public void testOnUploadWhenConcurrentUpdateSessionInfoIsNull() {
+        final ObservablePath path = mock(ObservablePath.class);
+        doReturn(path).when(versionRecordManager).getCurrentPath();
+
         presenter.onUpload();
 
-        verify(view).submit(versionRecordManagerMock.getCurrentPath());
+        verify(view).submit(path);
 
         assertNull(presenter.getConcurrentUpdateSessionInfo());
     }
@@ -209,37 +230,54 @@ public class DecisionTableXLSEditorPresenterTest {
 
         verify(busyIndicatorView).hideBusyIndicator();
         verify(presenter).showConcurrentUpdateError();
+        verify(versionRecordManager, never()).reloadVersions(versionRecordManager.getCurrentPath());
+    }
+
+    @Test
+    public void testOnUploadSuccess() {
+        final ObservablePath path = mock(ObservablePath.class);
+        doReturn(null).when(versionRecordManager).getCurrentPath();
+        doReturn(path).when(versionRecordManager).getPathToLatest();
+
+        presenter.onUploadSuccess();
+        verify(versionRecordManager).getPathToLatest();
+        verify(versionRecordManager, never()).getCurrentPath();
+        verify(versionRecordManager).reloadVersions(path);
     }
 
     @Test
     public void testMakeMenuBar() {
-        doReturn(mock(Project.class)).when(workbenchContext).getActiveProject();
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(true).when(projectController).canUpdateProject(any());
 
         presenter.makeMenuBar();
 
         verify(fileMenuBuilder).addCopy(any(Path.class),
-                                        any(DefaultFileNameValidator.class));
+                                        any(AssetUpdateValidator.class));
         verify(fileMenuBuilder).addRename(any(Path.class),
-                                          any(DefaultFileNameValidator.class));
-        verify(fileMenuBuilder).addDelete(any(Path.class));
+                                          any(AssetUpdateValidator.class));
+        verify(fileMenuBuilder).addDelete(any(Path.class),
+                                          any(AssetUpdateValidator.class));
+        verify(fileMenuBuilder).addNewTopLevelMenu(alertsButtonMenuItem);
     }
 
     @Test
     public void testMakeMenuBarWithoutUpdateProjectPermission() {
-        doReturn(mock(Project.class)).when(workbenchContext).getActiveProject();
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(false).when(projectController).canUpdateProject(any());
 
         presenter.makeMenuBar();
 
         verify(fileMenuBuilder,
                never()).addCopy(any(Path.class),
-                                any(DefaultFileNameValidator.class));
+                                any(AssetUpdateValidator.class));
         verify(fileMenuBuilder,
                never()).addRename(any(Path.class),
-                                  any(DefaultFileNameValidator.class));
+                                  any(AssetUpdateValidator.class));
         verify(fileMenuBuilder,
-               never()).addDelete(any(Path.class));
+               never()).addDelete(any(Path.class),
+                                  any(AssetUpdateValidator.class));
+        verify(fileMenuBuilder).addNewTopLevelMenu(alertsButtonMenuItem);
     }
 
     private class ServiceMock
@@ -277,7 +315,9 @@ public class DecisionTableXLSEditorPresenterTest {
             @Override
             public DecisionTableXLSContent loadContent(Path path) {
                 DecisionTableXLSContent content = new DecisionTableXLSContent();
-                content.setOverview(new Overview());
+                content.setOverview(new Overview() {{
+                    setMetadata(mock(Metadata.class));
+                }});
                 remoteCallback.callback(content);
                 return null;
             }
