@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,6 +18,9 @@ package org.drools.workbench.screens.guided.dtable.client.editor;
 
 import java.util.Collections;
 import java.util.List;
+import java.util.Set;
+import java.util.function.Supplier;
+
 import javax.annotation.PostConstruct;
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
@@ -26,19 +29,25 @@ import javax.inject.Inject;
 
 import com.google.gwt.core.client.Scheduler;
 import com.google.gwt.user.client.ui.IsWidget;
+import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.EditMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.InsertMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.RadarMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.ViewMenuBuilder;
+import org.drools.workbench.screens.guided.dtable.client.editor.page.ColumnsPage;
 import org.drools.workbench.screens.guided.dtable.client.type.GuidedDTableResourceType;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableModellerView;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableView;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorContent;
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService;
+import org.guvnor.common.services.shared.metadata.model.Metadata;
+import org.guvnor.common.services.shared.metadata.model.Overview;
+import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.ioc.client.container.SyncBeanManager;
+import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.kie.workbench.common.widgets.client.popups.validation.ValidationPopup;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
@@ -48,10 +57,13 @@ import org.uberfire.client.annotations.WorkbenchPartTitle;
 import org.uberfire.client.annotations.WorkbenchPartView;
 import org.uberfire.client.callbacks.Callback;
 import org.uberfire.client.mvp.PlaceManager;
+import org.uberfire.client.mvp.UpdatedLockStatusEvent;
+import org.uberfire.ext.editor.commons.client.menu.common.SaveAndRenameCommandBuilder;
 import org.uberfire.lifecycle.OnClose;
 import org.uberfire.lifecycle.OnFocus;
 import org.uberfire.lifecycle.OnMayClose;
 import org.uberfire.lifecycle.OnStartup;
+import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.Menus;
@@ -65,6 +77,8 @@ import static org.uberfire.client.annotations.WorkbenchEditor.LockingStrategy.ED
 @WorkbenchEditor(identifier = "GuidedDecisionTableEditor", supportedTypes = {GuidedDTableResourceType.class}, lockingStrategy = EDITOR_PROVIDED)
 public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableEditorPresenter {
 
+    private final SaveAndRenameCommandBuilder<GuidedDecisionTable52, Metadata> saveAndRenameCommandBuilder;
+
     @Inject
     public GuidedDecisionTableEditorPresenter(final View view,
                                               final Caller<GuidedDecisionTableEditorService> service,
@@ -78,7 +92,10 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
                                               final RadarMenuBuilder radarMenuBuilder,
                                               final GuidedDecisionTableModellerView.Presenter modeller,
                                               final SyncBeanManager beanManager,
-                                              final PlaceManager placeManager) {
+                                              final PlaceManager placeManager,
+                                              final ColumnsPage columnsPage,
+                                              final SaveAndRenameCommandBuilder<GuidedDecisionTable52, Metadata> saveAndRenameCommandBuilder,
+                                              final AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder) {
         super(view,
               service,
               notification,
@@ -91,7 +108,11 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
               radarMenuBuilder,
               modeller,
               beanManager,
-              placeManager);
+              placeManager,
+              columnsPage,
+              alertsButtonMenuItemBuilder);
+
+        this.saveAndRenameCommandBuilder = saveAndRenameCommandBuilder;
     }
 
     @Override
@@ -190,25 +211,82 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
     @Override
     public void makeMenuBar() {
         if (canUpdateProject()) {
-            fileMenuBuilder
+            getFileMenuBuilder()
                     .addSave(getSaveMenuItem())
                     .addCopy(() -> getActiveDocument().getCurrentPath(),
-                             fileNameValidator)
-                    .addRename(() -> getActiveDocument().getLatestPath(),
-                               fileNameValidator)
-                    .addDelete(() -> getActiveDocument().getLatestPath());
+                             assetUpdateValidator)
+                    .addRename(getSaveAndRenameCommand())
+                    .addDelete(() -> getActiveDocument().getLatestPath(),
+                               assetUpdateValidator);
         }
 
-        this.menus = fileMenuBuilder
+        this.menus = getFileMenuBuilder()
                 .addValidate(() -> onValidate(getActiveDocument()))
                 .addNewTopLevelMenu(getEditMenuItem())
                 .addNewTopLevelMenu(getViewMenuItem())
                 .addNewTopLevelMenu(getInsertMenuItem())
                 .addNewTopLevelMenu(getRadarMenuItem())
                 .addNewTopLevelMenu(getVersionManagerMenuItem())
+                .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build())
                 .build();
     }
 
+    protected Command getSaveAndRenameCommand() {
+
+        return saveAndRenameCommandBuilder
+                .addPathSupplier(getPathSupplier())
+                .addValidator(assetUpdateValidator)
+                .addRenameService(service)
+                .addMetadataSupplier(getMetadataSupplier())
+                .addContentSupplier(getContentSupplier())
+                .addIsDirtySupplier(getIsDirtySupplier())
+                .build();
+    }
+
+    private Supplier<Path> getPathSupplier() {
+        return () -> versionRecordManager.getPathToLatest();
+    }
+
+    Supplier<GuidedDecisionTable52> getContentSupplier() {
+        return () -> getActiveDocument().getModel();
+    }
+
+    Supplier<Metadata> getMetadataSupplier() {
+
+        return () -> {
+
+            final Overview overview = getActiveDocument().getOverview();
+
+            return overview.getMetadata();
+        };
+    }
+
+    Supplier<Boolean> getIsDirtySupplier() {
+        return () -> {
+
+            final Integer originalHashCode = originalHashCode(getActiveDocument());
+            final Integer currentHashCode = currentHashCode(getActiveDocument());
+
+            return isDirty(originalHashCode, currentHashCode);
+        };
+    }
+
+    int originalHashCode(final GuidedDecisionTableView.Presenter dtPresenter) {
+        return dtPresenter.getOriginalHashCode();
+    }
+
+    int currentHashCode(final GuidedDecisionTableView.Presenter dtPresenter) {
+        return dtPresenter.getModel().hashCode();
+    }
+
+    Set<GuidedDecisionTableView.Presenter> getAvailableDecisionTables() {
+        return modeller.getAvailableDecisionTables();
+    }
+
+    FileMenuBuilder getFileMenuBuilder() {
+        return fileMenuBuilder;
+    }
+
     @Override
     public void onOpenDocumentsInEditor(final List<Path> selectedDocumentPaths) {
         throw new UnsupportedOperationException();
@@ -216,7 +294,7 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
 
     @Override
     public void getAvailableDocumentPaths(final Callback<List<Path>> callback) {
-        callback.callback(Collections.<Path>emptyList());
+        callback.callback(Collections.emptyList());
     }
 
     @Override
@@ -225,7 +303,11 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
         scheduleClosure(() -> placeManager.forceClosePlace(editorPlaceRequest));
     }
 
+    void onUpdatedLockStatusEvent(final @Observes UpdatedLockStatusEvent event) {
+        super.onUpdatedLockStatusEvent(event);
+    }
+
     void scheduleClosure(final Scheduler.ScheduledCommand command) {
         Scheduler.get().scheduleDeferred(command);
     }
-}
\ No newline at end of file
+}
