@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -20,7 +20,11 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Optional;
 import java.util.Set;
+import java.util.function.Supplier;
+import java.util.stream.Collectors;
+
 import javax.annotation.PostConstruct;
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
@@ -29,12 +33,12 @@ import javax.inject.Inject;
 
 import com.google.gwt.core.client.Scheduler;
 import com.google.gwt.user.client.ui.IsWidget;
-import org.drools.workbench.models.datamodel.imports.Imports;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.EditMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.InsertMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.RadarMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.ViewMenuBuilder;
+import org.drools.workbench.screens.guided.dtable.client.editor.page.ColumnsPage;
 import org.drools.workbench.screens.guided.dtable.client.type.GuidedDTableGraphResourceType;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableModellerView;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTablePresenter;
@@ -47,16 +51,21 @@ import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEdito
 import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorGraphModel;
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService;
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphEditorService;
+import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphSaveAndRenameService;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
+import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
 import org.jboss.errai.bus.client.api.messaging.Message;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.ioc.client.container.SyncBeanManager;
-import org.kie.workbench.common.services.shared.project.KieProjectService;
+import org.kie.soup.project.datamodel.imports.Imports;
+import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.kie.workbench.common.widgets.client.callbacks.CommandDrivenErrorCallback;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.kie.workbench.common.widgets.client.popups.validation.ValidationPopup;
+import org.kie.workbench.common.widgets.metadata.client.validation.AssetUpdateValidator;
+import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.client.annotations.WorkbenchEditor;
@@ -71,6 +80,7 @@ import org.uberfire.client.mvp.SaveInProgressEvent;
 import org.uberfire.client.mvp.UpdatedLockStatusEvent;
 import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
 import org.uberfire.ext.editor.commons.client.menu.MenuItems;
+import org.uberfire.ext.editor.commons.client.menu.common.SaveAndRenameCommandBuilder;
 import org.uberfire.ext.editor.commons.client.resources.i18n.CommonConstants;
 import org.uberfire.ext.editor.commons.version.events.RestoreEvent;
 import org.uberfire.ext.widgets.common.client.callbacks.DefaultErrorCallback;
@@ -102,9 +112,11 @@ import static org.uberfire.ext.widgets.common.client.common.ConcurrentChangePopu
 public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionTableEditorPresenter {
 
     private final Caller<GuidedDecisionTableGraphEditorService> graphService;
-    private final Caller<KieProjectService> projectService;
+    private final Caller<KieModuleService> moduleService;
+    private final Caller<GuidedDecisionTableGraphSaveAndRenameService> graphSaveAndRenameService;
     private final Event<SaveInProgressEvent> saveInProgressEvent;
     private final LockManager lockManager;
+    private final SaveAndRenameCommandBuilder<List<GuidedDecisionTableEditorContent>, Metadata> saveAndRenameCommandBuilder;
     protected ObservablePath.OnConcurrentUpdateEvent concurrentUpdateSessionInfo = null;
     protected Access access = new Access();
     protected Integer originalGraphHash;
@@ -117,7 +129,8 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
     public GuidedDecisionTableGraphEditorPresenter(final View view,
                                                    final Caller<GuidedDecisionTableEditorService> service,
                                                    final Caller<GuidedDecisionTableGraphEditorService> graphService,
-                                                   final Caller<KieProjectService> projectService,
+                                                   final Caller<KieModuleService> moduleService,
+                                                   final Caller<GuidedDecisionTableGraphSaveAndRenameService> graphSaveAndRenameService,
                                                    final Event<NotificationEvent> notification,
                                                    final Event<SaveInProgressEvent> saveInProgressEvent,
                                                    final Event<DecisionTableSelectedEvent> decisionTableSelectedEvent,
@@ -131,7 +144,10 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
                                                    final NewGuidedDecisionTableWizardHelper helper,
                                                    final SyncBeanManager beanManager,
                                                    final PlaceManager placeManager,
-                                                   final LockManager lockManager) {
+                                                   final LockManager lockManager,
+                                                   final ColumnsPage columnsPage,
+                                                   final SaveAndRenameCommandBuilder<List<GuidedDecisionTableEditorContent>, Metadata> saveAndRenameCommandBuilder,
+                                                   final AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder) {
         super(view,
               service,
               notification,
@@ -144,12 +160,16 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
               radarMenuBuilder,
               modeller,
               beanManager,
-              placeManager);
+              placeManager,
+              columnsPage,
+              alertsButtonMenuItemBuilder);
         this.graphService = graphService;
-        this.projectService = projectService;
+        this.moduleService = moduleService;
         this.saveInProgressEvent = saveInProgressEvent;
         this.helper = helper;
         this.lockManager = lockManager;
+        this.graphSaveAndRenameService = graphSaveAndRenameService;
+        this.saveAndRenameCommandBuilder = saveAndRenameCommandBuilder;
     }
 
     @PostConstruct
@@ -174,7 +194,7 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
     }
 
     void onNewDocument() {
-        projectService.call((org.guvnor.common.services.project.model.Package pkg) -> {
+        moduleService.call((org.guvnor.common.services.project.model.Package pkg) -> {
             helper.createNewGuidedDecisionTable(pkg.getPackageMainResourcesPath(),
                                                 "",
                                                 GuidedDecisionTable52.TableFormat.EXTENDED_ENTRY,
@@ -351,6 +371,13 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
 
     @Override
     protected void onDecisionTableSelected(final @Observes DecisionTableSelectedEvent event) {
+
+        final Optional<GuidedDecisionTableView.Presenter> dtPresenter = event.getPresenter();
+
+        if (!dtPresenter.isPresent()) {
+            initialiseEditorTabsWhenNoDocuments();
+        }
+
         super.onDecisionTableSelected(event);
 
         if (event.isLockRequired()) {
@@ -366,10 +393,10 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
             fileMenuBuilder
                     .addSave(getSaveMenuItem())
                     .addCopy(versionRecordManager::getCurrentPath,
-                             fileNameValidator)
-                    .addRename(versionRecordManager::getPathToLatest,
-                               fileNameValidator)
-                    .addDelete(versionRecordManager::getPathToLatest);
+                             assetUpdateValidator)
+                    .addRename(getSaveAndRenameCommand())
+                    .addDelete(versionRecordManager::getPathToLatest,
+                               assetUpdateValidator);
         }
 
         this.menus = fileMenuBuilder
@@ -380,9 +407,105 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
                 .addNewTopLevelMenu(getRadarMenuItem())
                 .addNewTopLevelMenu(getRegisteredDocumentsMenuItem())
                 .addNewTopLevelMenu(getVersionManagerMenuItem())
+                .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build())
                 .build();
     }
 
+    protected Command getSaveAndRenameCommand() {
+
+        return saveAndRenameCommandBuilder
+                .addPathSupplier(getPathSupplier())
+                .addValidator(getValidator())
+                .addRenameService(getGraphSaveAndRenameService())
+                .addMetadataSupplier(getMetadataSupplier())
+                .addContentSupplier(getContentSupplier())
+                .addIsDirtySupplier(getIsDirtySupplier())
+                .addSuccessCallback(onSuccess())
+                .build();
+    }
+
+    Supplier<Path> getPathSupplier() {
+        return () -> versionRecordManager.getPathToLatest();
+    }
+
+    AssetUpdateValidator getValidator() {
+        return assetUpdateValidator;
+    }
+
+    Caller<GuidedDecisionTableGraphSaveAndRenameService> getGraphSaveAndRenameService() {
+        return graphSaveAndRenameService;
+    }
+
+    Supplier<Metadata> getMetadataSupplier() {
+        return () -> {
+
+            final Overview overview = getActiveDocument().getOverview();
+
+            return overview.getMetadata();
+        };
+    }
+
+    Supplier<List<GuidedDecisionTableEditorContent>> getContentSupplier() {
+        return () -> getAvailableDecisionTables()
+                .stream()
+                .map(c -> new GuidedDecisionTableEditorContent(c.getModel(), c.getOverview(), c.getCurrentPath(), c.getLatestPath()))
+                .collect(Collectors.toList());
+    }
+
+    Supplier<Boolean> getIsDirtySupplier() {
+        return () -> isGuidedDecisionTablesDirty() || isGraphDirty() || isOverviewWidgetDirty();
+    }
+
+    boolean isGuidedDecisionTablesDirty() {
+
+        return getAvailableDecisionTables().stream().anyMatch(dtPresenter -> {
+
+            final Integer originalHashCode = originalHashCode(dtPresenter);
+            final Integer currentHashCode = currentHashCode(dtPresenter);
+
+            return isDirty(originalHashCode, currentHashCode);
+        });
+    }
+
+    boolean isGraphDirty() {
+        return isDirty(originalGraphHash, getCurrentHashCode());
+    }
+
+    int getCurrentHashCode() {
+        return buildModelFromEditor().hashCode();
+    }
+
+    boolean isOverviewWidgetDirty() {
+        return getOverviewWidget().isDirty();
+    }
+
+    OverviewWidgetPresenter getOverviewWidget() {
+        return overviewWidget;
+    }
+
+    int originalHashCode(final GuidedDecisionTableView.Presenter dtPresenter) {
+        return dtPresenter.getOriginalHashCode();
+    }
+
+    int currentHashCode(final GuidedDecisionTableView.Presenter dtPresenter) {
+        return dtPresenter.getModel().hashCode();
+    }
+
+    Set<GuidedDecisionTableView.Presenter> getAvailableDecisionTables() {
+        return modeller.getAvailableDecisionTables();
+    }
+
+    ParameterizedCommand<Path> onSuccess() {
+        return (path) -> {
+
+            final Set<GuidedDecisionTableView.Presenter> allDecisionTables = new HashSet<>(modeller.getAvailableDecisionTables());
+            final int size = allDecisionTables.size();
+            final SaveGraphLatch saveGraphLatch = new SaveGraphLatch(size, "Sava and Rename");
+
+            saveGraphLatch.saveDocumentGraph(path);
+        };
+    }
+
     @Override
     protected void enableMenus(final boolean enabled) {
         super.enableMenus(enabled);
@@ -574,6 +697,9 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
     }
 
     void onUpdatedLockStatusEvent(final @Observes UpdatedLockStatusEvent event) {
+
+        super.onUpdatedLockStatusEvent(event);
+
         if (editorPath == null) {
             return;
         }
@@ -730,7 +856,10 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
             if (dtGraphElementCount > 0) {
                 return;
             }
+            saveDocumentGraph(editorPath);
+        }
 
+        private void saveDocumentGraph(final Path editorPath) {
             final GuidedDecisionTableEditorGraphModel model = buildModelFromEditor();
             graphService.call(new RemoteCallback<Path>() {
                                   @Override
