@@ -3,15 +3,16 @@
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
- * 
- *      http://www.apache.org/licenses/LICENSE-2.0
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
-*/
+ */
 
 package org.drools.workbench.client.home;
 
@@ -25,9 +26,8 @@ import org.kie.workbench.common.screens.home.model.HomeShortcutLink;
 import org.kie.workbench.common.screens.home.model.ModelUtils;
 import org.uberfire.client.mvp.PlaceManager;
 
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.BUSINESS_DASHBOARDS;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.CONTENT_MANAGEMENT;
 import static org.kie.workbench.common.workbench.client.PerspectiveIds.DEPLOYMENTS;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.DROOLS_ADMIN;
 import static org.kie.workbench.common.workbench.client.PerspectiveIds.LIBRARY;
 import static org.kie.workbench.common.workbench.client.PerspectiveIds.SERVER_MANAGEMENT;
 import static org.uberfire.workbench.model.ActivityResourceType.PERSPECTIVE;
@@ -51,8 +51,8 @@ public class HomeProducer implements HomeModelProvider {
                                                             PERSPECTIVE);
         design.addLink(new HomeShortcutLink("projects",
                                             LIBRARY));
-        design.addLink(new HomeShortcutLink("dashboards",
-                                            BUSINESS_DASHBOARDS));
+        design.addLink(new HomeShortcutLink("pages",
+                                            CONTENT_MANAGEMENT));
 
         final HomeShortcut devOps = ModelUtils.makeShortcut("fa fa-gears",
                                                             "DevOps",
